<?php

/**
 * code #1 - update the post exceprt character length
 * @param integer
 * @return integer
 */
function my_excerpt_length($length) 
{
	return 65; 
}
add_filter('excerpt_length', 'my_excerpt_length');




/**
 * code #2 - replace 'Read more' text with new string same URL
 * @param string
 * @return string
 */ 
function new_excerpt_more($text) 
{  
	return ' [...]'; 

}
add_filter('excerpt_more', 'new_excerpt_more'); 






/**
 * code #3 - remove #more hash from post URL
 * @param string
 * @return string
 */
function remove_more_link_jump($post) {
  return '<a href="'.get_permalink($post->ID).'" class="read-more">'.'Read More...'.'</a>';
}
add_filter('excerpt_more', 'remove_more_link_jump');






/**
 * code #4 - remove automatic <p> tags in Wordpress editor
 */
remove_filter('the_content', 'wpautop');







/**
 * code #5 - removes excess Wordpress header tags from default themes. 
 *         feel free to customize the options to suit your own needs.
 */
function clean_wp_header() {
  remove_action('wp_head', 'wp_generator');
  remove_action('wp_head', 'rel_canonical');
  remove_action('wp_head', 'rsd_link');
  remove_action('wp_head', 'feed_links',2);
  remove_action('wp_head', 'feed_links_extra',3);
  remove_action('wp_head', 'wlwmanifest_link');
  remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0);
  remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
}
add_action('init', 'clean_wp_header');








/**
 * code #6 - append 'first' class onto the 1st <p> element in each post
 * source  - http://byjakewithlove.com/
 * @param string
 * @return string
 */
function first_paragraph($content){
	global $post;
	
	if ($post->post_type == "post") {
		return preg_replace('/<p([^>]+)?>/', '<p$1 class="first">', $content, 1);
	}
	else {
		return $content;
	}
}
add_filter('the_content', 'first_paragraph');







/**
 * code #7 - add post thumbnails into RSS feed
 * source  - http://www.wpfunction.me/
 * @param string
 * @return string
 */
function add_feed_post_thumbnail($content) {
	global $post;
	
	if(has_post_thumbnail($post->ID)) {
		$content = get_the_post_thumbnail($post->ID, 'thumbnail') . $content;
	}
	return $content;
}
add_filter('the_excerpt_rss', 'add_feed_post_thumbnail');
add_filter('the_content_feed', 'add_feed_post_thumbnail');






/**
 * code #8 - add & remove custom Wordpress social contacts from user profile
 * source  - http://wordpress.stackexchange.com/a/4125/8922
 * @param array
 * @return array
 */
function cusom_social_contact_links($contacts) {
  // Adding
  $contacts['twitter']  = 'Twitter';
  $contacts['youtube']  = 'YouTube';
  $contacts['dribbble'] = 'Dribbble';
    
  // Removing
  unset($contacts['yim']);
  unset($contacts['aim']);
  unset($contacts['jabber']);
 
  return $contacts;
}
add_filter('user_contactmethods','cusom_social_contact_links', 10, 1); 







/**
 * code #9 - display custom admin menu with all links
 * source  - http://wordpress.stackexchange.com/a/1614/8922
 */
function full_admin_settings_links() {
  add_options_page(__('All Settings'), __('All Settings'), 'administrator', 'options.php');
}
add_action('admin_menu', 'full_admin_settings_links');







/**
 * code #10 - remove width/height HTML attributes from images
 * source   - http://css-tricks.com/snippets/wordpress/remove-width-and-height-attributes-from-inserted-images/
 * @param string
 * @return string
 */
function remove_image_size_atts($html) {
    $html = preg_replace('/(width|height)=\"\d*\"\s/', "", $html);
    return $html;
}
add_filter('post_thumbnail_html', 'remove_image_size_atts', 10);
add_filter('image_send_to_editor', 'remove_image_size_atts', 10);







/**
 * code #11 - remove Wordpress update message for everyone except Admin users
 * source   - http://wordpress.stackexchange.com/a/1585/8922
 */
global $user_login;
get_currentuserinfo();
if(!current_user_can('update_plugins')) { 
  add_action('init', create_function('$a', "remove_action('init', 'wp_version_check');" ), 2);
  add_filter('pre_option_update_core', create_function('$a', "return null;"));
}





/** 
 * code #12 - remove header meta tags from blog posts and pages.
 *       feel free to customize the options to suit your needs.
 * source   - http://wordpress.stackexchange.com/a/1569/8922
 */
function remove_default_post_metatags() {
 remove_meta_box('postcustom','post','normal');
 remove_meta_box('postexcerpt','post','normal');
 remove_meta_box('commentstatusdiv','post','normal'); 
 remove_meta_box('trackbacksdiv','post','normal');
 remove_meta_box('slugdiv','post','normal'); 
 remove_meta_box('authordiv','post','normal');
}
add_action('admin_menu','remove_default_post_metatags');

function remove_default_page_metatags() {
 remove_meta_box('postcustom','page','normal'); 
 remove_meta_box('postexcerpt','page','normal');
 remove_meta_box('commentstatusdiv','page','normal');
 remove_meta_box('trackbacksdiv','page','normal');
 remove_meta_box('slugdiv','page','normal');
 remove_meta_box('authordiv','page','normal');
}
add_action('admin_menu','remove_default_page_metatags');






/** 
 * code #13 - add post thumbnails into "manage posts/pages" admin table
 * source   - http://wordpress.stackexchange.com/a/6021/8922
 */
if(!function_exists('add_thumb_column') && function_exists('add_theme_support')) {
  add_theme_support('post-thumbnails', array('post', 'page'));

  function add_thumb_column($cols) {
    $cols['thumbnail'] = __('Thumbnail');
    return $cols;
  }

  function add_thumb_value($column_name, $post_id) {
    $width = 35;
    $height = 35;

    if('thumbnail' == $column_name ) {
      $thumbnail_id = get_post_meta($post_id, '_thumbnail_id', true);
      
      $attachments = get_children(array('post_parent' => $post_id, 'post_type' => 'attachment', 'post_mime_type' => 'image'));
      
      
      if($thumbnail_id)
        $thumb = wp_get_attachment_image($thumbnail_id, array($width, $height), true);
      elseif($attachments) {
        foreach($attachments as $attachment_id => $attachment) {
          $thumb = wp_get_attachment_image($attachment_id, array($width, $height), true);
         }
       }
       if(isset($thumb) && $thumb) {
         echo $thumb;
       } else {
         echo __('None');
       }
    }
  }
  
  add_filter('manage_posts_columns', 'add_thumb_column');
  add_action('manage_posts_custom_column', 'add_thumb_value', 10, 2);

  add_filter('manage_pages_columns', 'add_thumb_column');
  add_action('manage_pages_custom_column', 'add_thumb_value', 10, 2);
}




/**
 * code #14 - display Wordpress database query times and memory consumption in footer
 * source   - http://wordpress.stackexchange.com/a/1866/8922
 */
function footer_stats_display($visible = false) {
  $stat = sprintf( '%d queries in %.3f seconds, using %.2fMB memory',
    get_num_queries(),
    timer_stop( 0, 3 ),
    memory_get_peak_usage() / 1024 / 1024);

  echo $visible ? $stat : "<!-- {$stat} -->" ;
}
add_action('wp_footer', 'footer_stats_display', 20);






/**
 * code #15 - output the current post/page template name in your header area
 * source   - http://wordpress.stackexchange.com/a/3848/8922
 */
function display_template_name() {
  global $template;
  print_r($template);
}
add_action('wp_head', 'display_template_name');




/**
 * code #16 - customize the admin page footer text
 * source   - http://wordpress.stackexchange.com/a/6005/8922
 */
function custom_admin_footer() {
  echo 'add your custom footer text and html here';
} 
add_filter('admin_footer_text', 'custom_admin_footer');




/**
 * code #17 - sharpen JPG/JPEG images when auto-resized in Wordpress
 * source   - http://wordpress.stackexchange.com/a/35526/8922
 * @param string
 * @return resource
 */
function sharpen_resized_jpeg_images($resized_file) {
  $image = wp_load_image($resized_file);
    
  if(!is_resource($image))
    return new WP_Error('error_loading_image', $image, $file);

  $size = @getimagesize($resized_file);
  if(!$size)
    return new WP_Error('invalid_image', __('Could not read image size'), $file);
    
  list($orig_w, $orig_h, $orig_type) = $size;

  switch($orig_type) {
    case IMAGETYPE_JPEG:
      $matrix = array(
        array(-1, -1, -1),
        array(-1, 16, -1),
        array(-1, -1, -1),
      );

      $divisor = array_sum(array_map('array_sum', $matrix));
      $offset = 0; 
      
      imageconvolution($image, $matrix, $divisor, $offset);
      imagejpeg($image, $resized_file,apply_filters('jpeg_quality', 90, 'edit_image'));
      break;
    case IMAGETYPE_PNG:
      return $resized_file;
    case IMAGETYPE_GIF:
      return $resized_file;
  }

  return $resized_file;
}   
add_filter('image_make_intermediate_size', 'sharpen_resized_jpeg_images', 900);





/**
 * code #18 - remove 'comments' column from pages admin table
 * source   - http://wordpress.stackexchange.com/a/9990/8922
 * @param array
 * @return array
 */
function remove_comments_column($defaults) {
    unset($defaults['comments']);
    return $defaults;
}
add_filter('manage_pages_columns', 'remove_comments_column');






/**
 * code #19 - display a custom Wordpress codex search in the admin dashboard
 * source   - http://wordpress.stackexchange.com/a/3805/8922
 */
function wp_codex_search_form() {
  echo '<form target="_blank" method="get" action="http://wordpress.org/search/do-search.php" class="alignright" style="margin: 11px 5px 0;">
    <input type="text" onblur="this.value=(this.value==\'\') ? \'Search the Codex\' : this.value;" onfocus="this.value=(this.value==\'Search the Codex\') ? \'\' : this.value;" maxlength="150" value="Search the Codex" name="search" class="text"> <input type="submit" value="Go" class="button" />
  </form>';
}
add_filter('in_admin_header', 'wp_codex_search_form', 11);




 
/** 
 * code #20 - get TinyURL for any post or page via shortcode tag
 * source   - http://wordpress.stackexchange.com/a/5741/8922
 * ex: [tinyurl] will output the TinyURL for the current page
 *     [tinyurl url="http://google.com/" title="google"] will output the TinyURL for Google.com
 */
function custom_tinyurl_shortcode($atts){
  extract(shortcode_atts(array(
   'url' => get_permalink(),
   'title' => ''
  ), $atts));
  
  if(!$title) $title = $url;

  if(false === ($cache = get_transient('tinyurl_'+md5($url)))):
    $cache = wp_remote_retrieve_body(wp_remote_get('http://tinyurl.com/api-create.php?url='.$url));
    // cached for 24 hours
    set_transient('tinyurl_'+md5($url), $cache, 60*60*24); 
  endif;

  return '<a href="'.esc_url($cache).'">'.esc_attr($title).'</a>';
}
add_shortcode('tinyurl', 'custom_tinyurl_shortcode');


?>